@@ -544,6 +544,9 @@ class Dataset(DatasetMeta):
         if not os.path.exists(os.path.dirname(file_name)):
             os.makedirs(os.path.dirname(file_name), 0o0755)
 
+        while file_path.endswith('/'):
+            file_path = file_path[:-1]
+
         obj_url = file_name[len(file_path) + 1:]
 
         return key, file_name, obj_url
